==> dojo_1.11.0+dfsg.orig.tar.gz: dojo-release-1.11.0-src/dojo/cldr/nls/sv/coptic.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "lördag denna vecka",
	"field-sat-relative+1": "lördag nästa vecka",
	"field-dayperiod": "fm/em",
	"field-sun-relative+-1": "söndag förra veckan",
	"field-mon-relative+-1": "måndag förra veckan",
	"field-minute": "Minut",
	"field-day-relative+-1": "i går",
	"field-weekday": "Veckodag",
	"field-day-relative+-2": "i förrgår",
	"field-era": "Era",
	"field-hour": "timme",
	"field-sun-relative+0": "söndag denna vecka",
	"field-sun-relative+1": "söndag nästa vecka",
	"months-standAlone-abbr": [
		"Tout",
		"Bâbâ",
		"Hâtour",
		"Kiahk",
		"Toubah",
		"Amshîr",
		"Barmahât",
		"Barmoudah",
		"Bashans",
		"Ba’ounah",
		"Abîb",
		"Misra",
		"Al-nasi"
	],
	"field-wed-relative+-1": "onsdag förra veckan",
	"field-day-relative+0": "i dag",
	"field-day-relative+1": "i morgon",
	"field-day-relative+2": "i övermorgon",
	"field-tue-relative+0": "tisdag denna vecka",
	"field-zone": "Tidszon",
	"field-tue-relative+1": "tisdag nästa vecka",
	"field-week-relative+-1": "förra veckan",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "nästa år",
	"field-sat-relative+-1": "lördag förra veckan",
	"field-year-relative+-1": "i fjol",
	"field-year": "År",
	"field-fri-relative+0": "fredag denna vecka",
	"field-fri-relative+1": "fredag nästa vecka",
	"months-standAlone-wide": [
		"Tout",
		"Bâbâ",
		"Hâtour",
		"Kiahk",
		"Toubah",
		"Amshîr",
		"Barmahât",
		"Barmoudah",
		"Bashans",
		"Ba’ounah",
		"Abîb",
		"Misra",
		"Al-nasi"
	],
	"field-week": "Vecka",
	"field-week-relative+0": "denna vecka",
	"field-week-relative+1": "nästa vecka",
	"months-format-abbr": [
		"tout",
		"bâbâ",
		"hâtour",
		"kiahk",
		"toubah",
		"amshîr",
		"barmahât",
		"barmoudah",
		"bashans",
		"ba’ounah",
		"abîb",
		"misra",
		"al-nasi"
	],
	"field-month-relative+0": "denna månad",
	"field-month": "Månad",
	"field-month-relative+1": "nästa månad",
	"field-fri-relative+-1": "fredag förra veckan",
	"field-second": "Sekund",
	"field-tue-relative+-1": "tisdag förra veckan",
	"field-day": "Dag",
	"field-mon-relative+0": "måndag denna vecka",
	"field-mon-relative+1": "måndag nästa vecka",
	"field-thu-relative+0": "torsdag denna vecka",
	"field-second-relative+0": "nu",
	"field-thu-relative+1": "torsdag nästa vecka",
	"field-wed-relative+0": "onsdag denna vecka",
	"months-format-wide": [
		"tout",
		"bâbâ",
		"hâtour",
		"kiahk",
		"toubah",
		"amshîr",
		"barmahât",
		"barmoudah",
		"bashans",
		"ba’ounah",
		"abîb",
		"misra",
		"al-nasi"
	],
	"field-wed-relative+1": "onsdag nästa vecka",
	"field-month-relative+-1": "förra månaden",
	"field-thu-relative+-1": "torsdag förra veckan"
}
//end v1.x content
);

==> dojo_1.14.2+dfsg1.orig.tar.gz: dojo-release-1.14.2-src/dojo/cldr/nls/sv/coptic.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "lördag denna vecka",
	"field-sat-relative+1": "lördag nästa vecka",
	"field-dayperiod": "fm/em",
	"field-sun-relative+-1": "söndag förra veckan",
	"field-mon-relative+-1": "måndag förra veckan",
	"field-minute": "Minut",
	"field-day-relative+-1": "i går",
	"field-weekday": "Veckodag",
	"field-day-relative+-2": "i förrgår",
	"field-era": "Era",
	"field-hour": "Timme",
	"field-sun-relative+0": "söndag denna vecka",
	"field-sun-relative+1": "söndag nästa vecka",
	"months-standAlone-abbr": [
		"Tout",
		"Bâbâ",
		"Hâtour",
		"Kiahk",
		"Toubah",
		"Amshîr",
		"Barmahât",
		"Barmoudah",
		"Bashans",
		"Ba’ounah",
		"Abîb",
		"Misra",
		"Al-nasi"
	],
	"field-wed-relative+-1": "onsdag förra veckan",
	"field-day-relative+0": "i dag",
	"field-day-relative+1": "i morgon",
	"field-day-relative+2": "i övermorgon",
	"field-tue-relative+0": "tisdag denna vecka",
	"field-zone": "Tidszon",
	"field-tue-relative+1": "tisdag nästa vecka",
	"field-week-relative+-1": "förra veckan",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "nästa år",
	"field-sat-relative+-1": "lördag förra veckan",
	"field-year-relative+-1": "i fjol",
	"field-year": "År",
	"field-fri-relative+0": "fredag denna vecka",
	"field-fri-relative+1": "fredag nästa vecka",
	"months-standAlone-wide": [
		"Tout",
		"Bâbâ",
		"Hâtour",
		"Kiahk",
		"Toubah",
		"Amshîr",
		"Barmahât",
		"Barmoudah",
		"Bashans",
		"Ba’ounah",
		"Abîb",
		"Misra",
		"Al-nasi"
	],
	"field-week": "Vecka",
	"field-week-relative+0": "denna vecka",
	"field-week-relative+1": "nästa vecka",
	"months-format-abbr": [
		"tout",
		"bâbâ",
		"hâtour",
		"kiahk",
		"toubah",
		"amshîr",
		"barmahât",
		"barmoudah",
		"bashans",
		"ba’ounah",
		"abîb",
		"misra",
		"al-nasi"
	],
	"field-month-relative+0": "denna månad",
	"field-month": "Månad",
	"field-month-relative+1": "nästa månad",
	"field-fri-relative+-1": "fredag förra veckan",
	"field-second": "Sekund",
	"field-tue-relative+-1": "tisdag förra veckan",
	"field-day": "Dag",
	"field-mon-relative+0": "måndag denna vecka",
	"field-mon-relative+1": "måndag nästa vecka",
	"field-thu-relative+0": "torsdag denna vecka",
	"field-second-relative+0": "nu",
	"field-thu-relative+1": "torsdag nästa vecka",
	"field-wed-relative+0": "onsdag denna vecka",
	"months-format-wide": [
		"tout",
		"bâbâ",
		"hâtour",
		"kiahk",
		"toubah",
		"amshîr",
		"barmahât",
		"barmoudah",
		"bashans",
		"ba’ounah",
		"abîb",
		"misra",
		"al-nasi"
	],
	"field-wed-relative+1": "onsdag nästa vecka",
	"field-month-relative+-1": "förra månaden",
	"field-thu-relative+-1": "torsdag förra veckan"
}
//end v1.x content
);
